@@ -23,9 +23,9 @@
 #' sample_gtfs <- read_gtfs(u1)
 #' attach(sample_gtfs)
 #' #list routes by the number of stops they have
-#' routes_df %>% inner_join(trips_df, by="route_id") %>%
-#'   inner_join(stop_times_df) %>% 
-#'     inner_join(stops_df, by="stop_id") %>% 
+#' routes %>% inner_join(trips, by="route_id") %>%
+#'   inner_join(stop_times) %>% 
+#'     inner_join(stops, by="stop_id") %>% 
 #'       group_by(route_long_name) %>%
 #'         summarise(stop_count=n_distinct(stop_id)) %>%
 #'           arrange(desc(stop_count))
@@ -35,29 +35,27 @@ read_gtfs <- function(path, local = FALSE,
                       geometry=FALSE,
                       frequency=FALSE) {
   # download zip file
-  if(!local) {
+  if (!local) {
     path <- download_from_url(url = path, quiet = quiet)
-    if(is.null(path)) { return() }
+    if (is.null(path)) { 
+      return() 
+    }
   }
-  
   # extract zip file
   tmpdirpath <- unzip_file(path, quiet=quiet)
-  
   file_list_df <- zip::zip_list(path)
-  if(!exists("file_list_df")) {
+  if (!exists("file_list_df")) {
     stop(sprintf("No files found in zip"))
   }
-  
-  gtfs_obj <- create_gtfs_object(tmpdirpath, file_list_df$filename, quiet = quiet)
-  
-  if(geometry) {
+  gtfs_obj <- create_gtfs_object(tmpdirpath, 
+                                 file_list_df$filename, 
+                                 quiet = quiet)
+  if (geometry) {
     gtfs_obj <- gtfs_as_sf(gtfs_obj,quiet=quiet)
   }
-  
-  if(frequency) {
+  if (frequency) {
     gtfs_obj <- get_route_frequency(gtfs_obj) 
   }
-  
   return(gtfs_obj) 
 }
 
@@ -84,9 +82,9 @@ read_gtfs <- function(path, local = FALSE,
 #' sample_gtfs <- import_gtfs(u1)
 #' attach(sample_gtfs)
 #' #list routes by the number of stops they have
-#' routes_df %>% inner_join(trips_df, by="route_id") %>%
-#'   inner_join(stop_times_df) %>%
-#'     inner_join(stops_df, by="stop_id") %>%
+#' routes %>% inner_join(trips, by="route_id") %>%
+#'   inner_join(stop_times) %>%
+#'     inner_join(stops, by="stop_id") %>%
 #'       group_by(route_long_name) %>%
 #'         summarise(stop_count=n_distinct(stop_id)) %>%
 #'           arrange(desc(stop_count))
@@ -107,11 +105,14 @@ import_gtfs <- function(path, local = FALSE, quiet = FALSE) {
 #'
 #' @keywords internal
 
-download_from_url <- function(url, path=tempfile(fileext = ".zip"), quiet=FALSE) {
+download_from_url <- function(url,
+                              path=tempfile(fileext = ".zip"),
+                              quiet=FALSE) {
   
   stopifnot(length(url) == 1)
   
-  # check if single element of dataframe was inputed. if so, convert to single value; error otherwise.
+  # check if single element of dataframe 
+  # was inputed. if so, convert to single value; error otherwise.
   if(!is.null(dim(url))) {
     if(all(dim(url) == c(1,1))) {
       url <- unlist(url, use.names = FALSE)
@@ -240,7 +241,7 @@ unzip_file <- function(zipfile,
 
 create_gtfs_object <- function(tmpdirpath, file_paths, quiet = FALSE) {
   prefixes <- vapply(file_paths,get_file_shortname,FUN.VALUE = "")
-  df_names <- paste(prefixes,"_df",sep="")
+  df_names <- prefixes
   if(!quiet) message('Reading files in feed...\n')
   gtfs_obj <- lapply(file_paths, 
                    function(x) read_gtfs_file(x, 
@@ -252,7 +253,7 @@ create_gtfs_object <- function(tmpdirpath, file_paths, quiet = FALSE) {
   if(!quiet) message('Reading files in feed... done.\n')
   
     
-  gtfs_obj <- validate_gtfs(gtfs_obj, quiet = quiet)
+  gtfs_obj <- gtfs_validate(gtfs_obj, quiet = quiet)
   
   stopifnot(is_gtfs_obj(gtfs_obj))
   
@@ -292,15 +293,15 @@ get_file_shortname <- function(file_path) {
   split_path <- strsplit(file_path, '/')
   file_name <- split_path[[1]][length(split_path[[1]])]
 
-  prefix <- gsub('.txt|-new', '', file_name) 
-  # suffix '.*-new.txt' comes from trillium data
-  prefix <- gsub('\\-|\\.', '_', prefix)
+  prefix <- gsub(".txt|-new", "", file_name) 
+  # suffix ".*-new.txt" comes from trillium data
+  prefix <- gsub("\\-|\\.", "_", prefix)
   return(prefix)
 }
 
 #' Parses one gtfs file
 #'
-#' @param prefix Character. gtfs file prefix (e.g. 'agency', 'stop_times', etc.)
+#' @param prefix Character. gtfs file prefix (e.g. "agency", "stop_times", etc.)
 #' @param file_path Character. file path
 #' @param quiet Boolean. Whether to output messages and files found in folder.
 #' @return Dataframe of parsed GTFS file.
@@ -314,43 +315,70 @@ parse_gtfs_file <- function(prefix, file_path, quiet = FALSE) {
   stopifnot(!is.na(file.size(file_path)))
   if(file.size(file_path) > 1) {
 
-    ## get correct meta data using file prefix (e.g. 'agency', 'stop_times')
+    ## get correct meta data using file prefix (e.g. "agency", "stop_times")
     meta <- get_gtfs_meta()[[prefix]]
 
     # check if a file is empty. If so, return NULL.
-    L <- suppressWarnings(length(scan(file_path, what = "", quiet = TRUE, sep = '\n')))
+    L <- suppressWarnings(
+      length(
+        scan(
+          file_path, 
+          what = "", 
+          quiet = TRUE, 
+          sep = "\n")
+        )
+      )
     if(L < 1) {
       s <- sprintf("   File '%s' is empty.", basename(file_path))
       if(!quiet) message(s)
       return(NULL)
     }
 
-    # if no meta data is found for a file type but file is not empty, read as is.
+    #if no meta data is found for a file 
+    #type but file is not empty, read as is.
     if(is.null(meta)) {
-      s <- sprintf("   File %s not recognized, trying to read file as csv.", basename(file_path))
+      s <- sprintf("File %s not recognized, 
+                   trying to read file as csv.", 
+                   basename(file_path))
       if(!quiet) message(s)
 
       tryCatch({
-        df <- suppressMessages(data.table::fread(file = file_path, sep=","))
-      }, error = function(error_condition) {
-        s <- sprintf("   File could not be read as csv.", basename(file_path))
-        if(!quiet) message(s)
-        return(NULL)
-      })
+        df <- suppressMessages(
+          data.table::fread(file = file_path, 
+                            sep=","))
+        }, 
+        error = function(error_condition) {
+          s <- sprintf("   File could not be read as csv.", basename(file_path))
+          if(!quiet) message(s)
+          return(NULL)
+        })
       return(df)
     }
 
-    ## read.csv supports UTF-8-BOM. use this to get field names.
-    small_df <- suppressWarnings(utils::read.csv(file_path, nrows = 5, stringsAsFactors = FALSE)) # get a small df to find how many cols are needed
+    # read.csv supports UTF-8-BOM. use this to get field names.
+    # get a small df to find how many cols are needed
+    small_df <- suppressWarnings(
+      utils::read.csv(
+        file_path, 
+        nrows = 5, 
+        stringsAsFactors = FALSE)) 
 
-    ## get correct coltype, if possible
-    coltypes_character <- rep('c', dim(small_df)[2]) # create 'c' as coltype defaults
-    names(coltypes_character) <- names(small_df) %>% tolower()
-    indx <- match(names(coltypes_character), meta$field)  # indx from valid cols in meta$field. NAs will return for invalid cols
+    # get correct coltype, if possible
+    # create "c" as coltype defaults
+    coltypes_character <- rep("c", 
+                              dim(small_df)[2]) 
 
-    ## !is.na(indx) = valid col in 'coltype' found in meta$field
-    ## indx[!is.na(indx)] = location in 'meta$coltype' where corresponding type is found
-    coltypes_character[!is.na(indx)] <- meta$coltype[indx[!is.na(indx)]] # valid cols found in small_df
+    names(coltypes_character) <- 
+      names(small_df) %>% tolower()
+    # indx from valid cols in meta$field. NAs will return for invalid cols
+    indx <- match(names(coltypes_character), meta$field)  
+
+    #!is.na(indx) = valid col in 'coltype' found in meta$field
+    #indx[!is.na(indx)] = location in 'meta$coltype' 
+    #where corresponding type is found
+    #valid cols found in small_df
+    coltypes_character[!is.na(indx)] <- 
+      meta$coltype[indx[!is.na(indx)]] 
 
     # use col_*() notation for column types
     coltypes <-
@@ -366,20 +394,38 @@ parse_gtfs_file <- function(prefix, file_path, quiet = FALSE) {
     if (has_bom(file_path)) { # check for BOM. if yes, use read.csv()
       ## switch function
       converttype <- function(x, y) {
-        switch(x, character = as.character(y), integer = as.integer(y), double = as.double(y), Date = lubridate::ymd(y))
+        switch(x, 
+               character = as.character(y), 
+               integer = as.integer(y), 
+               double = as.double(y), 
+               Date = lubridate::ymd(y))
       }
-      colnms <- meta$field[indx] # get expected/required names for columns. these are imposed.
-      
+      #get expected/required names for columns. 
+      #these are imposed.
+      colnms <- meta$field[indx] 
       ## get colclasses
-      colclasses <- sapply(coltypes_character, switch, c = "character", i = "integer", d = "double", "D" = "Date")
+      colclasses <- sapply(coltypes_character, 
+                           switch, 
+                           c = "character", 
+                           i = "integer", 
+                           d = "double", 
+                           "D" = "Date")
       
-      csv <- quote(utils::read.csv(file_path, col.names = colnms, stringsAsFactors= FALSE))
+      csv <- quote(utils::read.csv(file_path, 
+                                   col.names = colnms, 
+                                   stringsAsFactors= FALSE))
       df <- try(suppressWarnings(eval(csv)) %>%
-          mapply(converttype, x = colclasses, y = ., SIMPLIFY = FALSE) %>% # ensure proper column types
-          tibble::as_tibble())
+              mapply(converttype,
+                     # ensure proper column types
+                     x = colclasses,
+                     y = ., SIMPLIFY = FALSE) %>% 
+              tibble::as_tibble())
 
       if(any(class(df) %in% "try-error")) {
-        probs <- "Error during import. Likely encoding error. Note that utils::read.csv() was used, not readr::read_csv()."
+        probs <- "Error during import. 
+                  Likely encoding error. 
+                  Note that utils::read.csv() 
+                  was used, not readr::read_csv()."
         attributes(df) <- append(attributes(df), list(problems = probs))
       }
     } else {
